@@ -1,8 +1,7 @@
 from tinderbotz.session import Session
 
-from tinderbotz.helpers.location_helper import LocationHelper
 from tinderbotz.helpers.profile_helper import ProfileHelper
-
+from tinderbotz.helpers.preferences_helper import PreferencesHelper
 from tinderbotz.helpers.geomatch import Geomatch
 from tinderbotz.helpers.match import Match
 from tinderbotz.helpers.geomatch_helper import GeomatchHelper
@@ -12,3 +11,4 @@ from tinderbotz.helpers.storage_helper import StorageHelper
 from tinderbotz.helpers.loadingbar import LoadingBar
 
 from tinderbotz.helpers.constants_helper import *
+from tinderbotz.helpers.xpaths import *
